@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,6 +31,11 @@ static void kaddressbook_options(QCommandLineParser *parser)
             QStringLiteral("import"),
             i18n("Import the given file")));
 
+    parser->addOption(
+        QCommandLineOption(
+            QStringLiteral("newcontact"),
+            i18n("Open the 'New Contact' dialog")));
+
     parser->addPositionalArgument(
         QStringLiteral("urls"),
         i18n("Files or URLs. The user will be asked whether to import."),
