@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2009-2017 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ class KAddressBookPart : public KParts::ReadOnlyPart
 
 public:
     KAddressBookPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
-    virtual ~KAddressBookPart();
+    ~KAddressBookPart() override;
 
 public Q_SLOTS:
     void newContact();
