@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class KAddressBookPluginInterface : public PimCommon::PluginInterface
     Q_OBJECT
 public:
     explicit KAddressBookPluginInterface(QObject *parent = nullptr);
-    ~KAddressBookPluginInterface();
+    ~KAddressBookPluginInterface() override;
 
     void setMainWidget(MainWidget *mainWidget);
 
